@@ -62,7 +62,7 @@ print "ok - 1\\n";
 exit;
 END
     close(TEST);
-    mysystem(q{perl test.pl});
+    mysystem(qq{$^X test.pl});
 
     open(TEST,">test.pl") || die "Can't open file: test.pl, q(;_;)bad!!\n";
     binmode TEST;
@@ -75,7 +75,7 @@ print "ok - 1\\n";
 exit;
 END
     close(TEST);
-    mysystem(q{perl test.pl});
+    mysystem(qq{$^X test.pl});
 
     for my $file (
         "$encoding.pm",
@@ -150,10 +150,10 @@ END
     while (my $file = <CHAR_MANIFEST>) {
         chomp $file;
         if ($file =~ m{^x?t/$encoding/.*\.t$}) {
-            print ENCODING_MANIFEST $file, "\n";
             open(FILE1,$file) || die "Can't open file: $file, q(;_;)bad!!\n";
             binmode FILE1;
             (my $file2 = $file) =~ s#^xt/#t/#;
+            print ENCODING_MANIFEST $file2, "\n";
             open(FILE2,">$encoding/$file2") || die "Can't open file: $encoding/$file2, q(;_;)bad!!\n";
             binmode FILE2;
             while (<FILE1>) {
@@ -170,14 +170,14 @@ END
     close(ENCODING_MANIFEST);
 
     mychdir($encoding);
-    mysystem(q{perl pMakefile.PL});
+    mysystem(qq{$^X pMakefile.PL});
     if ($^O eq 'MSWin32') {
-        mysystem(q{pmake.bat dist});
+        mysystem(qq{$^X pmake.bat dist});
     }
     else {
-        mysystem(q{./pmake dist});
+        mysystem(qq{$^X ./pmake dist});
     }
-    mysystem(q{perl test.pl});
+    mysystem(qq{$^X test.pl});
     mychdir('..');
 }
 
